----
title: Opaque functions
description: Details on using opaque functions
order: 4
----

Opaque functions can be introduced in IML code to represent computations
whos internal details are to be treated as unknown, either because they
are unknown to the modeller, or because the modeller does not want to
model them, or because the modeller does not want ImandraX to reason about
them.
